function P = mpower(A,n);
%MPOWER   Matrix power of 2-D polynomial
%
% P=MPOWER(A,n) or P=A^n
% compute the n-th power of the 2-D polynomial matrix
% A - POL2-class 2-D polynomial matrix (square)
% n - nonnegative integer exponent

if nargin<2,
   error('Not enough input arguments.');
end;
if ~isa(n,'double') | any(size(n)~=1) | ~isreal(n) | floor(n)~=n,
   error('Invalid power; must be integer scalar.');
elseif n~=0 & log2(abs(n))>=52,
    error('The (abs of) power is too large. Use an argument up to 2^52.')
elseif ~isa(A,'pol2'),
    error('The matrix is not POL2 class.');
elseif size(A)~=fliplr(size(A));
    error('Matrix is not square.');
end;

if n<0,
   eval('A = inv(A);','error(peel(lasterr));');
   n = -n;
end;

%-----------------

% if A.d==[0,0],  % constant matrix
%     P=pol2(()^n)

N = fliplr(num2str(dec2bin(n))); % power of 2 chain

Z = A;
F = pol2(eye(size(A)));
lN = length(N);
for k = 1:lN,
   if N(k)=='1',
      F = mtimes(F,Z);
   end;   %if
   if k<lN,
      Z = mtimes(Z,Z);		% no zeroing yet
   end;
end; 	%for
P = F;

P=pzer(P);

%end .. pol2/mpower