function P=pol2(varargin);
% Fuction P=pol2(...)
% is a converter/constructor into the POL2 class.
% 
% P=pol2(M,var) - accepted matrices M are POL or DOUBLE classes:
% MxN    - the resulting matrix P is a constant matrix
%          M-by-N (constant coefficients of 2-D polynomial
%          contained only). 
%          Optional parameter var without impact.
%
% MxNxK  - the resulting matrix P is a constant matrix
%          M-by-N with degree K-1 in default variable.
%          Default variable is 'x'. To choose the variable 
%          'y' write P=pol2(M,'y').
%
% MxNxKxL- the resulting matrix P is a constant matrix
%          M-by-N with degree K-1 in variable 'x' and 
%          degree L-1 in degree 'y'.
%
% Possible var values 'x','y'.
% 
% See also FLIPXY, FLIPUD, FLIPLR, FLIPCOEF


% quit check + quit exit 
if isa(varargin{1},'pol2') & nargin==1,
%      P=varargin{1};
%     [row,col,x_var,y_var]=size(P.c);
%      if x_var-1~=P.d(1);
%          error(['The variable "',inputname(1),'" prove wrong degree-consistence in the x-variable']);
%      elseif y_var-1~=P.d(2);
%          error(['The variable "',inputname(1),'" prove wrong degree-consistence in the y-variable']);
%      end;
      P = varargin{1};
      return;
end;
%-----------

if nargin==2 & ~(varargin{2}=='x' | varargin{2}=='y'),
        error('Only ''x'' or ''y'' allowed as explicite 2nd argument.');
elseif nargin==1,
   varargin{2}='x'; % pad the input string to two variables
elseif nargin>2,
   error('Too many input arguments.');
end;
%-----------------
P.d = [0,0];  % separate degree entry for each variable
P.s = [0,0]; % size of matrix
P.c = zeros([0,0,0,0]); % 
P.v = ['x','y'];
P.u = [];   % J.Jezek
%-----------------
if isa(varargin{1},'pol'),
    v=varargin{1};
    SizeP=size(varargin{1});
    P.d=[v.d,[0]];
    Pc=zeros([SizeP(1),SizeP(2),v.d+1,1]);
    Pc(:,:,:,1)=v.c;
    if nargin==1,                                      %
       warning('Variable symbol changed to ''x''.');   % J.Jezek
    end;                                               %
    if varargin{2}=='y';
        Pc=permute(Pc,[1 2 4 3]);
        P.d=[[0],v.d];
    end;
    P.c=Pc;
    P.s=v.s;
elseif isa(varargin{1},'double')
    v=varargin{1};
    SizeP=size(varargin{1});
    if ndims(v)==2,
        SizeP(3:4)=[1,1];
    elseif ndims(v)==3,
        SizeP(4)=1;
    elseif ndims(v)>4,
        error('DOUBLE has too many dimensions.');
    end;
    if SizeP(1)~=0 & SizeP(2)~=0,    % J.Jezek
       P.d=[SizeP(3)-1,SizeP(4)-1];  %
    else                             %
       P.d = [];                     %
    end;                             %
    Pc=zeros(SizeP(1),SizeP(2),SizeP(3),SizeP(4));
    Pc(:,:,:,:)=v;
    if (varargin{2}=='y')&(ndims(v)==3);
        Pc=permute(Pc,[1 2 4 3]);
        P.d=fliplr(P.d);
    end;
    P.c=Pc;
    P.s=([SizeP(1),SizeP(2)]);
else
    error('Just POL, 4-D DOUBLE or 3-D DOUBLE object can be used as argument.');
end;

superiorto('double','pol');
P = class(P,'pol2');
P = pzer(P);
P = pclear(P);

%end .. @pol2/pol2
