function Ps = prod(P,dim);
%PROD    Element-wise product of 2-D polynomial
%
% For  vectors, PROD(X) is the product of the elements of X. 
% For matrices, PROD(X) is a row vector with the product over each column. 
%
% PROD(X,DIM) works along the dimension DIM.

if nargin==1, dim = [];
end;

Pc = P.c;
Psi = P.s;
Pd = P.d;
Pv = P.v;

if isempty(dim),
   if isempty(Pd),
      Ps = pol2(prod(zeros(Psi)));
      return;
   end;
   dim = find(Psi~=1);
   if isempty(dim),
      dim = 1;
   else
      dim = dim(1);
   end;
end;
if ~isa(dim,'double') | length(dim)~=1  | (dim~=1 & dim~=2),
   error('Invalid dimension.');
end;

if isempty(Pd),
   Ps = pol2(prod(zeros(Psi),dim));
   return;
end;

switch dim,
 case 1,
  Ps = ones(1,Psi(2));
  Pi.d = Pd; Pi.s = [1 Psi(2)]; 
  for i = 1:Psi(1),
    Pi.c = Pc(i,:,:,:); Pi.v = Pv; Pi.u = [];
    Pip = class(Pi, 'pol2');
    Ps = times(Ps, Pip);
  end;

 case 2
  Ps = ones(Psi(1), 1);
  Pi.d = Pd; Pi.s = [Psi(1) 1]; 
  for i=1:Psi(2),
    Pi.c = Pc(:,i,:,:); Pi.v = Pv; Pi.u = [];
    Pip = class(Pi, 'pol2');
    Ps = times(Ps, Pip);
 end;
 
end;	% switch

