function P = subsref(P,S)
%SUBSREF   Subscripted reference for 2-D polynomial
%
if nargin<2,
   error('Not enough input arguments.');
end;
if ~isstruct(S),
   error('Invalid 2nd argument.');
end;

P_size = size(P); Pd = P.d;
S_lg = length(S); S1 = S(1);
St1 = S1.type; Ss1 = S1.subs;
Ss1_lg = length(Ss1);
switch St1,
case '.',
   flstr = lower(Ss1); flstr1 = flstr(1);
   switch flstr1,
   case 'd', P = Pd;
      S(1) = [];
      if ~isempty(S),
         if ~isempty(P),
               eval('P = subsref(P,S);', ...
                       ['if isa(P,''pol2''),', ...
                       'error(peel(lasterr)); else error(peelf(lasterr)); end;']);
         else
            S1 = S(1); St1 = S1.type;
            switch St1,
            case '.',
               error('Attempt to reference field of non-structure array.');
            case '{}',
               error('Cell content reference from a non-cell array object.');
            case '()',
               P = [];
            end;
         end;
      end;
      return;
   case 's', P = P_size;
   case 'c', P = P.c;
   case 'v', P = P.v;
   case 'u', P = P.u;
   otherwise,
      error('Invalid field in subscripted reference.');
   end;
   
case'()',
   if Ss1_lg>2,
      error('More than two subscripts.');
   end;
   Sp1 = Ss1{1}; Sp1_size = size(Sp1);
   compose1 = 0; compose2 = 0;
   if Ss1_lg==1 & (isa(Sp1,'pol2') | isa(Sp1,'pol')),
      if any(P_size~=1),
         if any(Sp1_size~=1),
            error('Invalid argument; must be scalar polynomial.');
         end;
      else
         if Sp1_size(1)~=Sp1_size(2),
            error('Invalid argument; must be square matrix polynomial.');
         end;
      end;
      compose1 = 1; compclass = class(Sp1);
   end;
   if Ss1_lg==2,
      Sp2 = Ss1{2}; Sp2_size = size(Sp2);
      if isa(Sp1,'pol2'),
         eval('Sp2 = pol2(Sp2);',...
            'error(''2nd argument cannot be converted to pol2.'');');
         compose2 = 1; compclass = 'pol2';
      elseif isa(Sp2,'pol2'),
         eval('Sp1 = pol2(Sp1);',...
            'error(''1st argument cannot be converted to pol2.'');');
         compose2 = 1; compclass = 'pol2';
      elseif isa(Sp1,'pol'),
         eval('Sp2 = pol(Sp2);',...
            'error(''2nd argument cannot be converted to pol.'');');
         compose2 = 1; compclass = 'pol';
      elseif isa(Sp2,'pol'),
         eval('Sp1 = pol(Sp1);',...
            'error(''1st argument cannot be converted to pol.'');');
         compose2 = 1; compclass = 'pol';
      end;
      if compose2,
         if any(P_size~=1),
            if any(Sp1_size~=1),
               error('Invalid 1st argument, must be scalar polynomial.');
            end;
            if any(Sp2_size~=1),
               error('Invalid 2nd argument, must be scalar polynomial,');
            end;
         else
            if Sp1_size(1)~=Sp1_size(2),
               error('Invalid 1st argument; must be square matrix.');
            end;
            if Sp2_size(1)~=Sp2_size(2),
               error('Invalid 2nd argument; must be square matrix;');
            end;
            if Sp1_size(1)~=1 & Sp2_size(1)~=1,
               error('Only one argument may be matrix, the other one must be scalar.');
            end;
         end;
      end;
   end;
   
   if compose1 | compose2,  % composition of 2-D polynomials
      if ~any(P_size==0),
         if any(Pd<0),
            if Sp1_size(1)~=1,
               P = zeros(Sp1_size);
            elseif compose2 & Sp2_size(1)~=1,
               P = zeros(Sp2_size);
            end;
            if strcmp(compclass,'pol2'), P = pol2(P);
            else P = pol(P);
            end;
         else
            I = eye(Sp1_size);
            if compose2 & Sp2_size(1)~=1,
               I = eye(Sp2_size);
            end;
            Pd1 = Pd(1); Pd2 = Pd(2);
            Z = P.c(:,:,Pd1+1,Pd2+1)*I;
            if Pd2>0,
               if compose1, Sp2 = Sp1;
               end;
               for l = Pd2:-1:1,
                  Z = Z*Sp2 + P.c(:,:,Pd1+1,1)*I;
               end;
            end;
            if Pd1>0,
               for k = Pd1:-1:1,
                  Q = P.c(:,:,k,Pd2+1)*I;
                  if Pd2>0,
                     if ~compose2,
                        error('Not enough input arguments.');
                     end;
                     for l = Pd2:-1:1,
                        Q = Q*Sp2 + P.c(:,:,k,l)*I;
                     end;
                  end;
                  Z = Z*Sp1 + Q;
               end;
            end;
            if strcmp(compclass,'pol2'), P = Z;
            else P = pol(Z);
            end;
         end;
      end;
      
   else   % subscripting of 2-D polynomial   
      if isempty(Pd) | any(isinf(Pd)),
         Pd = [0 0]; P.c = zeros(P_size);
      end;
      if Ss1_lg==2,
         Ppc = P.c; S1.subs{3} = ':'; S1.subs{4} = ':';
      elseif isempty(P),  % ???
         Ppc = zeros(P_size);
      else
         Ppc = reshape(P.c,[P_size(1)*P_size(2),1,Pd(1)+1,Pd(2)+1]);
         S1.subs{2} = [1]; S1.subs{3} = ':'; S1.subs{4} = ':';
      end;
      if Ss1_lg>=1,
         i1 = Ss1{1};
         if isnumeric(i1) & ~isempty(i1) & i1<=0,
            error('Index into matrix is negative or zero.');
         end;
      end;
      if Ss1_lg>=2,
         i2 = Ss1{2};
         if isnumeric(i2) & ~isempty(i2) & 12<=0,
            error('Index into matrix is negative or zero.');
         end;
      end;
      Px = 0;
      eval('Px = subsref(Ppc,S1);','error(peelf(lasterr));');
      [ps1,ps2,ps3,ps4] = size(Px);
      P.d = [ps3-1,ps4-1];
      if ~ps1 | ~ps2,
         P.d = []; Px = zeros(ps1,ps2,0,0);
      end;
      P.s = [ps1,ps2];
      P.c = Px;
      P.u = [];
      P = pclear(P);   
   end;
   
case '{}',
   if Ss1_lg>2,
      error('More than two subscripts in {} .');
   end;
   if Ss1_lg==1,
      if isempty(Pd) | Pd(2)<=0,
         Sp1 = Ss1{1}; Sp2 = 0;
      elseif Pd(1)<=0,
         Sp1 = 0; Sp2 = Ss1{1};
      else
         error('Two subscripts in {} needed.');
      end;
   else
      Sp1 = Ss1{1}; Sp2 = Ss1{2};
   end;
   
   Sp = [Sp1 Sp2];
   S1.type = '()';
   S1.subs{1} = ':'; S1.subs{2} = ':';
   S1.subs{3} = Sp1; S1.subs{4} = Sp2;
   if isempty(Pd) | any(isinf(Pd)),
      Pd = [0 0]; Ppc = zeros(P_size);
      Sp = zeros(size(Sp));
      Sp1 = Sp(1); Sp2 = Sp2;
   else
      Ppc = P.c;
   end;
      
   casechar = 0; casepol2 = 0;
   if isnumeric(Sp1),
      if ischar(Sp2),
         casechar = 1; Spchar = Sp2;
      elseif isa(Sp2,'pol2'),
         casepol2 = 1; Sppol2 = Sp2;
      end;
      Spnum = Sp1;
   elseif isnumeric(Sp2),
      if ischar(Sp1),
         casechar = 1; Spchar = Sp1;
      elseif isa(Sp1,'pol2'),
         casepol2 = 1; Sppol2 = Sp1;
      end;
      Spnum = Sp2;
   end;
   
   casex = 0; casey = 0;
   if casechar,
      if strcmp(Spchar,'x'), casex = 1;
      elseif strcmp(Spchar,'y'), casey = 1;
      end;
   end;
   if casepol2,
      [vs1,vs2,vd1,vd2] = size(Sppol2.c);
      if all([vs1,vs2,vd1,vd2]==[1 1 2 1]) & ...
            all(Sppol2.c(:)==[0;1]),
         casex = 1;
      elseif all([vs1,vs2,vd1,vd2]==[1 1 1 2]) & ...
            all(Sppol2.c(:)==[0;1]),
         casey = 1;
      end;
   end;
      
   if casex | casey,
      if length(Spnum)~=1 | ~isreal(Spnum) | Spnum<0 | ...
            ~isfinite(Spnum) | floor(Spnum)~=Spnum,
         error('Invalid subscript in {} .');
      end;
      if casex,
         if Spnum > Pd(1),
            Ppc = zeros(P_size(1),P_size(2));
         else
            Ppc = P.c(:,:,Spnum+1,:);
         end;
         P = pol2(Ppc,'y');
      elseif casey,
         if Spnum > Pd(2),
            Ppc = zeros(P_size(1),P_size(2));
         else
            Ppc = P.c(:,:,:,Spnum+1);
         end;
         P = pol2(Ppc,'x');   
      end;
         
   else
      if isa(Sp1,'double'),
         if any(any(~isfinite(Sp1))),
            error('Subscript in {} is not finite.');
         end;
         if any(any(Sp1<0)),
            Spmin1 = min(min(Sp1));
            Ppc = cat(3,zeros(P_size(1),P_size(2),...
               -Spmin1,size(Ppc,4)),Ppc);
            Sp1 = Sp1-Spmin1;
%            error('Subscript in {} is negative.');
         end;
         Spmax1 = max(max(Sp1));
         if Spmax1>Pd(1),
            Ppc = cat(3,Ppc,zeros(P_size(1),P_size(2),...
               Spmax1-Pd(1),size(Ppc,4)));
         end;
         S1.subs{3} = Sp1+1;
      end;
      if isa(Sp2,'double'),
         if any(any(~isfinite(Sp2))),
            error('Subscript in {} is not finite.');
         end;
         if any(any(Sp2<0)),
            Spmin2 = min(min(Sp2));
            Ppc = cat(4,zeros(P_size(1),P_size(2),...
               size(Ppc,3),-Spmin2),Ppc);
            Sp2 = Sp2-Spmin2;
%            error('Subscript in {} is negative.');
         end;
         Spmax2 = max(max(Sp2));
         if Spmax2>Pd(2),
            Ppc = cat(4,Ppc,zeros(P_size(1),P_size(2),...
               size(Ppc,3),Spmax2-Pd(2)));
         end;
         S1.subs{4} = Sp2+1;
      end;
      eval('Ppc = subsref(Ppc,S1);','error(peelf(lasterr));');
      P = Ppc;
   end;
   
otherwise
   error('Invalid 2nd argument.');
end;

S(1) = [];
if ~isempty(S),
   eval('P = subsref(P,S);', ...
      ['if isa(P,''pol2''),', ...
      'error(peel(lasterr)); else error(peelf(lasterr)); end;']);   
end;
   
%end .. @pol2/subsref
