function Z = value(F,X,Y)
%VALUE     Value of 2-D polynomial
%
% The command  Z = VALUE(X,Y)  returns matrix Z
% whose every entry Z(i,j) is the value of
% 2-D polynomial function F(i,j) of the arguments
% X(i,j) and Y(i,j).
%
% Matrices F,X,Y must have the same dimension unless
% some of them is scalar. In such a case, the scalar
% operates with every entry of the other matrices.
%
% When F is a function of X only, the argument Y plays
% no role. It may be any scalar or any compatible matrix
% or it may be omitted. Similarly, when F is a function
% of Y only, the argument X may be omitted. When F is
% empty or constant, both X and Y may be omitted.
%
% Matrices X,Y or some entries of them may be infinite.

ni = nargin;
if ni>=2,
   if ~isa(X,'double') | ndims(X)>2,
      error('Invalid 2nd argument.');
   end;
end;
if ni==3,
   if ~isa(Y,'double') | ndims(Y)>2,
      error('Invalid 3rd argument.');
   end;
end;

sF = size(F);
if ni>=2,
   sX = size(X);
   if any(sF~=sX),
      if all(sX==1),
         X = repmat(X,sF);
      elseif all(sF==1),
         F = repmat(F,sX); sF = size(F);
      else
         error('Matrices not of the same dimensions.');
      end;
   end;
end;
if ni==3,
   sY = size(Y);
   if any(sF~=sY),
      if all(sY==1),
         Y = repmat(Y,sF);
      elseif all(sF==1),
         F = repmat(F,sY); sF = size(F);
         X = repmat(X,sY);
      else
         error('Matrices not of the same dimensions.');
      end;
   end;
end;

Z = zeros(sF);
Fd = F.d;
if any(sF==0) | any(Fd<0), return;
end;

Fd1 = Fd(1); Fd2 = Fd(2);
Z = F.c(:,:,Fd1+1,Fd2+1);
if Fd2>0,
   if ni==2, Y = X;
   elseif ni==1,
      error('Not enough input arguments.');
   end;
   for l = Fd2:-1:1,
      Z = Z.*Y + F.c(:,:,Fd1+1,l);
   end;
end;
if Fd1>0,
   for k = Fd1:-1:1,
      G = F.c(:,:,k,Fd2+1);
      if ni==1,
         error('Not enough input arguments.');
      end;
      if Fd2>0,
         if ni==2,
            error('Not enough input arguments.');
         end;
         for l = Fd2:-1:1,
            G = G.*Y + F.c(:,:,k,l);
         end;
      end;
      Z = Z.*X + G;
   end;
end;

%end .. @pol2/value

