function C=mtimes(A,B);
% MTIMES (*) 
% compute the product of two POL2SP matrices
%

if nargin < 2,
   error('Incorrect number of inputs.');
elseif nargout > 1,
   error('Incorrect number of outputs.');
end;

A=pol2sp(A);
B=pol2sp(B);

As=size(A);
Bs=size(B);

if all(As==[1,1]) | all(Bs==[1,1]),
    C=A.*B; % went over to the element-by-element multiplication    
    
elseif As(2)==Bs(1),
    Nsp=2.^(ceil(log2(A.d+B.d+[1,1])));
    [A,B]=msl(A,B,Nsp);

    C.d = A.d+B.d;  % separate degree entry for each variable
    C.n = Nsp;  % number of used spectra-points
    C.s = [As(1),Bs(2)]; % size of matrix
    C.c = zeros([As(1),Bs(2),C.n]); 
    C.v = ['x','y'];
    C.u = [];
    C.k = A.k & B.k;
    
    if C.k==1 % clever trick - for real coefficients work with 1/2 of spectra
        Nsp_aux=[0,0];
%         if Nsp(1)>=8,
%             Nsp_aux(1)=Nsp(1)/2+1;
%         else,
%             Nsp_aux(1)=Nsp(1);
%         end;
            
        if Nsp(2)>=8,
            Nsp_aux(2)=Nsp(2)/2+1;
        else,
            Nsp_aux(2)=Nsp(2);
        end;
        
        for pos_x=1:Nsp(1), %Nsp_aux(1)
            for pos_y=1:Nsp_aux(2),
                C.c(:,:,pos_x,pos_y)=A.c(:,:,pos_x,pos_y)*B.c(:,:,pos_x,pos_y);
            end;
        end;
        % mirroring 
        if Nsp_aux(2)<Nsp(2),
            C.c(:,:,:,Nsp_aux(2)+1:Nsp(2))=C.c(:,:,:,2:Nsp_aux(2)-1);
        end;
        
    elseif C.k~=1 % coefficients are not real
        for pos_x=1:Nsp(1),
            for pos_y=1:Nsp(2),
                C.c(:,:,pos_x,pos_y)=A.c(:,:,pos_x,pos_y)*B.c(:,:,pos_x,pos_y);
            end;
        end;
    end;

    C=class(C,'pol2sp');
else,
   error ('Inner matrix dimensions must agree.');
end;