function P2sp=pol2sp(varargin);
% POL2SP constructor
% The S=POL2SP(P,N) function compute the spectra
% of the 2-D polynomial matrix P (class POL2).
% Result of this function S is a matrix with the
% same size like the origin - now class POL2SP.
% N is a optional paramter vector [Nx,Ny] to set
% the numbers of resulting spectral points.
% If parameter N is empty or set insufficient
% number of points a number of points is used
% which satisfy the conditions for FFT (radix-2)
% algorithm.

if isa(varargin{1},'pol2sp'),
    P2sp=varargin{1};
    return;
elseif isa(varargin{1},'double'),
    varargin{1}=pol2(varargin{1},'xy');
elseif ~isa(varargin{1},'pol2'),
    error('Wrong argument class.');
end;

% dopsat jeste noznost TSP2

if nargin==1, %just a POL2 object as argument
    P2=varargin{1};
    Nsp=2.^(ceil(log2(P2.d+[1,1]))); % minimal number of points
elseif nargin==2,
    P2=pol2(varargin{1});
    Nsp_opt=2.^(ceil(log2(P2.d+[1,1])));
    if isempty(varargin{2}),
        Nsp=Nsp_opt; 
    elseif size(varargin{2})~=[1,2],
        error('Wrong size of 2nd argument. It has to be a 1x2 integer vector.');
    elseif any(varargin{2}<Nsp_opt);
        Nsp=Nsp_opt;
    else
        Nsp=varargin{2};
    end;
end;
    
P2sp.d = P2.d;  % separate degree entry for each variable
P2sp.n = Nsp;  % number of used spectra-points
P2sp.s = P2.s; % size of matrix
P2sp.c = zeros([0,0,0,0]); % 
P2sp.v = ['x','y'];
P2sp.u = [];
P2sp.k = isreal(varargin{1}.c);

%-----------------
P2sp.c=fft(fft(P2.c,Nsp(1),3),Nsp(2),4);

P2sp=class(P2sp,'pol2sp');




    
    
