function P = power(A,n);
% P=POWER(A,n) or P=A.^n
% compute the n-th element-wise power of the POL2SP matrix
% A - POL2SP-class 2-D polynomial matrix
% n - nonnegative integer exponent, may be matrix compatible with A


if nargin<2,
   error('Not enough input arguments.');
end;
if ~isa(n,'double') | ndims(n)>2 | ~isreal(n) | ...
      (~isempty(n) & (any(any(n<0)) | any(any(floor(n)~=n)))),
   error('Invalid power; must be nonnegative integer.');
end;

if ~isa(A,'POL2SP'),
   error('Matrix is not POL2SP object.');
end;

if
A=msl(A,(A.n).*n);

A.c=(A.c).^n;
A.d=A.d*n;

P=A;