function [Str_out] = char(X)
%CHAR  Convert two-sided 2-D polynomial to a cell matrix with chars

Xs = X.s;
Xv = X.v;
Xd = X.p.d;
if isempty(Xd) | any(isinf(Xd)),  % J.Jezek
   Xc = zeros(Xs(1),Xs(2),0,0);   %
   Xd = [1 1];                    %
end;                              %
Xc = X.p.c;
Xo = X.o;
Str_out=cell(Xs(1),Xs(2)); % output matrix

Str_Mtr=cell(Xd(1)+1,Xd(2)+1); % Cell-matrix of generated string terms
Str_Vctr=cell(1,(Xd(1)+1)*(Xd(2)+1));

% String-terms for further string compilation
%---------------------
for d1i=0:Xd(1),
    d1io = d1i + Xo(1);
    for d2i=0:Xd(2),
        d2io = d2i + Xo(2);
        if d1io==0, % check for variable u
            u_str='';
        elseif d1io==1,
            u_str='u';
        else,
            u_str=strcat('u^',num2str(d1io));
        end;
        
        if d2io==0, % check for variable w
            w_str='';
        elseif d2io==1,
            w_str='w';
        else,
            w_str=strcat('w^',num2str(d2io));
        end;
        
        % the string compilation for one coefficient
        if isempty(u_str) & isempty(w_str), % to bypass the exception
            Str_Mtr{d1i+1,d2i+1}='';
        elseif xor(isempty(u_str),isempty(w_str)),
            Str_Mtr{d1i+1,d2i+1}=strcat(u_str,w_str);
        else,
            Str_Mtr{d1i+1,d2i+1}=strcat(u_str,'*',w_str);
        end; % if isempty(x_str) & isempty(x_str),
            
    end;
end;  %for d1i=0:Xd(1),
%---------------------
% Vector of string-terms ; diagonal by diagonal - X first
Pos_In_Vctr=1;
if Xd(1)==0, % extract diagonals from a horizontal vector - just y-polynomial
    Str_Vctr=Str_Mtr;
elseif Xd(2)==0, % extract diagonals from a vertical vector - just x-polynomial
    Str_Vctr=Str_Mtr';
elseif Xd(1)~=0 & Xd(2)~=0, % extract diagonals from a matrix
    Str_Mtr=flipud(Str_Mtr); % x-first
    for diag_indx=-Xd(1):Xd(2),
        diag_tmp=diag(Str_Mtr,diag_indx)';
        Length_diag=length(diag_tmp);
        Str_Vctr(Pos_In_Vctr:Pos_In_Vctr+Length_diag-1)=diag_tmp;
        Pos_In_Vctr=Pos_In_Vctr+Length_diag;
    end; %for
end; % if
%---------------------
clear Str_Mtr Pos_In_Vctr Length_diag diag_tmp
%------------------- The String-Term-Vector is now created ----
%--------------------------------------------------------------

Coe_Mtr=zeros(Xd(1)+1,Xd(2)+1);  % matrix of coefficients
N_chars=0;
% Sort coefficients by sum of variable power 
for ri=1:Xs(1),
    for ci=1:Xs(2),
        Coe_Mtr=squeeze(Xc(ri,ci,:,:)); %2-D matrix for work with
        if Xd(1)==0, % exception - too many dimesions have been squeezed
%           Coe_Mtr=Coe_Mtr';   J.Jezek  27-Apr-2003
            Coe_Mtr=Coe_Mtr.';
        end; 
        Pos_In_Vctr=1;
        % Vector asembling---------
        Coe_Vctr=zeros(1,(Xd(1)+1)*(Xd(2)+1));
        if Xd(1)==0, % extract diagonals from a horizontal vector 
            Coe_Vctr=Coe_Mtr;
        elseif Xd(2)==0, % extract diagonals from a vertical vector
%           Coe_Vctr=Coe_Mtr';      J.Jezek  27-Apr-2003
            Coe_Vctr=Coe_Mtr.';           
        elseif Xd(1)~=0 & Xd(2)~=0,
            Coe_Mtr=flipud(Coe_Mtr);
            for diag_indx=-Xd(1):Xd(2),
%               diag_tmp=diag(Coe_Mtr,diag_indx)';   J.Jezek 27-Apr-2003
                diag_tmp=diag(Coe_Mtr,diag_indx).';
                Length_diag=length(diag_tmp);
                Coe_Vctr(Pos_In_Vctr:Pos_In_Vctr+Length_diag-1)=diag_tmp;
                Pos_In_Vctr=Pos_In_Vctr+Length_diag;
            end; %for
        end; %if 
        %--------------------------
        % Finishing ----- Coeff & strings
        length_Vctr=length(Coe_Vctr);
        Str_out{ri,ci}=[];
        Str_out_aux=[];
        for Pos_indx=1:length_Vctr,
            if isreal(Coe_Vctr(Pos_indx)),
                if Coe_Vctr(Pos_indx)==-1 & ~isempty(Str_Vctr{Pos_indx}),
                    Str_out_aux=[Str_out_aux,' - ',Str_Vctr{Pos_indx}];
                elseif Coe_Vctr(Pos_indx)<0,
                    Str_out_aux=[Str_out_aux,' - ',num2str(abs(Coe_Vctr(Pos_indx))),Str_Vctr{Pos_indx}];
                elseif Coe_Vctr(Pos_indx)==1 & ~isempty(Str_Vctr{Pos_indx}),
                    Str_out_aux=[Str_out_aux,' + ',Str_Vctr{Pos_indx}];
                elseif Coe_Vctr(Pos_indx)>0,
                    Str_out_aux=[Str_out_aux,' + ',num2str(Coe_Vctr(Pos_indx)),Str_Vctr{Pos_indx}];
                end;
            else % complex coefficients
                Str_out_aux=[Str_out_aux,' + (',num2str(Coe_Vctr(Pos_indx)),')',Str_Vctr{Pos_indx}];
                
            end %if isreal(Coe_Vctr(Pos_indx))
        end;
        %----------------
       
        if isempty(Str_out_aux),
            Str_out_aux='0';
        elseif Str_out_aux(2)=='+', % handle the exception ' + 10x ...' -> ' 10x ...'
            Str_out_aux(1:2)='';
        end;
        Str_out{ri,ci}=Str_out_aux;
    end; % for ci=1:Xs(2),
end;   % for ri=1:Xs(1),

%end .. @tsp2/char


