function P = pzer(P, zeroing)
%PZER  Perform zeroing on a polynomial matrix P
%
% P = PZER(P) sets the coefficients in P whose absolute value is less
% than the current value of global zeroing tolerance equal to zero.
%
% P = PZER(P,ZEROING) uses the value of argument ZEROING as the 
% local tolerance.
% 
% To suppres zeroing globally set the global zeroing tolerance equal to zero.


%  No effect on other properties.

global PGLOBAL;
eval('in_tol=PGLOBAL.ZEROING;', 'painit;');
if nargin == 2,
   if ~isa(zeroing,'double') | length(zeroing)~=1 | ...
         ~isreal(zeroing),
      error('Invalid tolerance.');
   end;
   in_tol=zeroing;
elseif nargin < 1,
   error('Not enough input arguments.');
end;

if in_tol > 0, % if ZEROING <= 0, zeroing is not performed
   % first, set neglected entries to zero
   if isreal(P.p.c),
      P.p.c(abs(P.p.c)<in_tol)=0;
   else,
      Pr=real(P.p.c); Pi=imag(P.p.c);
      Pr(abs(Pr)<in_tol)=0;
      Pi(abs(Pi)<in_tol)=0;
      P.p.c=Pr+i*Pi;
   end;
end;

% second, remove zero leading coefficients
% that may have been introduced
P = pclear(P);

%end .. @pol/pzer 